@@ -19,7 +19,7 @@
 MulticoreFuture <- function(expr=NULL, envir=parent.frame(), substitute=FALSE, ...) {
   if (substitute) expr <- substitute(expr)
 
-  f <- MultiprocessFuture(expr=expr, envir=envir, job=NULL, ...)
+  f <- MultiprocessFuture(expr=expr, envir=envir, substitute=FALSE, job=NULL, ...)
   structure(f, class=c("MulticoreFuture", class(f)))
 }
 
@@ -49,29 +49,29 @@ run.MulticoreFuture <- function(future, ...) {
   assertOwner(future)
 
   mcparallel <- importMulticore("mcparallel")
-  expr <- future$expr
+
+  expr <- getExpression(future)
   envir <- future$envir
 
-  ## Inject code for the next future strategy to use.
-  expr <- injectNextStrategy(future, expr)
-
-  call <- substitute(parallel::mcparallel(e), list(e=expr))
-
   requestCore(await=function() FutureRegistry("multicore", action="collect-first"))
 
-  future$state <- 'running'
-
   ## Add to registry
   FutureRegistry("multicore", action="add", future=future)
 
-  job <- eval(call, envir=envir)
+  future.args <- list(expr)
+  job <- do.call(parallel::mcparallel, args=future.args, envir=envir)
+
   future$job <- job
+  future$state <- 'running'
 
   invisible(future)
 }
 
 #' @export
 resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
+  ## Is future even launched?
+  if (x$state == 'created') return(FALSE)
+
   ## Is value already collected?
   if (x$state %in% c('finished', 'failed', 'interrupted')) return(TRUE)
 
@@ -88,11 +88,16 @@ resolved.MulticoreFuture <- function(x, timeout=0.2, ...) {
   ## an ambigous value because the future expression may return NULL.
   ## WORKAROUND: Adopted from parallel::mccollect().
   pid <- selectChildren(job, timeout=timeout)
-  (is.integer(pid) || is.null(pid))
+  res <- (is.integer(pid) || is.null(pid))
+
+  ## Signal conditions early? (happens only iff requested)
+  if (res) signalEarly(x)
+
+  res
 }
 
 #' @export
-value.MulticoreFuture <- function(future, onError=c("signal", "return"), ...) {
+value.MulticoreFuture <- function(future, signal=TRUE, ...) {
   ## Has the value already been collected?
   if (future$state %in% c('finished', 'failed', 'interrupted')) {
     return(NextMethod("value"))
