@@ -75,18 +75,18 @@ def newsuper(typ=_SENTINEL, type_or_obj=_SENTINEL, framedepth=1):
         for typ in mro:
             #  Find the class that owns the currently-executing method.
             for meth in typ.__dict__.values():
-                if isinstance(meth, FunctionType):
-                    if meth.func_code is f.f_code:
-                        break   # Aha!  Found you.
-                elif isinstance(meth, staticmethod):
-                    if PY26:
-                        # Prior to Python 2.7, this contortion was necessary.
-                        # See http://bugs.python.org/issue5982.
-                        if meth.__get__(1).func_code is f.f_code:
-                            break   # Aha!  Found you.
-                    else:
-                        if meth.__func__.func_code is f.f_code:
-                            break   # Aha!  Found you.
+                # Drill down through any wrappers to the underlying func.
+                # This handles e.g. classmethod() and staticmethod().
+                try:
+                    while not isinstance(meth,FunctionType):
+                        try:
+                            meth = meth.__func__
+                        except AttributeError:
+                            meth = meth.__get__(type_or_obj)
+                except (AttributeError, TypeError):
+                    continue
+                if meth.func_code is f.f_code:
+                    break   # Aha!  Found you.
             else:
                 continue    #  Not found! Move onto the next class in MRO.
             break    #  Found! Break out of the search loop.
