@@ -19,6 +19,14 @@ class TestStr(unittest.TestCase):
         self.assertEqual(str('blah'), u'blah')  # u'' prefix: Py3.3 and Py2 only
         self.assertEqual(str(b'1234'), "b'1234'")
 
+    def test_bool_str(self):
+        s1 = str(u'abc')
+        s2 = u'abc'
+        s3 = str(u'')
+        s4 = u''
+        self.assertEqual(bool(s1), bool(s2))
+        self.assertEqual(bool(s3), bool(s4))
+
     def test_os_path_join(self):
         """
         Issue #15: can't os.path.join(u'abc', str(u'def'))
@@ -94,6 +102,16 @@ class TestStr(unittest.TestCase):
     def test_isinstance_str(self):
         self.assertTrue(isinstance(str('blah'), str))
 
+    def test_isinstance_str_subclass(self):
+        """
+        Issue #89
+        """
+        value = str(u'abc')
+        class Magic(str):
+            pass
+        self.assertTrue(isinstance(value, str))
+        self.assertFalse(isinstance(value, Magic))
+
     def test_str_getitem(self):
         s = str('ABCD')
         self.assertNotEqual(s[0], 65)
