@@ -16,18 +16,22 @@ import sys
 import copy
 
 from future.utils import with_metaclass
-from future.types.newobject import newobject
+from future.types.newobject import newobject, BaseNewObject
 
 
 _builtin_list = list
 ver = sys.version_info[:2]
 
 
-class BaseNewList(type):
+class BaseNewList(BaseNewObject):
     def __instancecheck__(cls, instance):
-        return isinstance(instance, _builtin_list)
+        if cls == newlist:
+            return isinstance(instance, _builtin_list)
+        else:
+            return issubclass(instance.__class__, cls)
 
-class newlist(with_metaclass(BaseNewList, _builtin_list, newobject)):
+
+class newlist(with_metaclass(BaseNewList, _builtin_list)):
     """
     A backport of the Python 3 list object to Py2
     """
