@@ -41,10 +41,11 @@ representations of your objects portably across Py3 and Py2, use the
 """
 
 from collections import Iterable
-
 from numbers import Number
+
 from future.utils import PY3, istext, with_metaclass, isnewbytes
 from future.types import no, issubset
+from future.types.newobject import newobject, BaseNewObject
 
 
 if PY3:
@@ -52,9 +53,12 @@ if PY3:
     unicode = str
 
 
-class BaseNewStr(type):
+class BaseNewStr(BaseNewObject):
     def __instancecheck__(cls, instance):
-        return isinstance(instance, unicode)
+        if cls == newstr:
+            return isinstance(instance, unicode)
+        else:
+            return issubclass(instance.__class__, cls)
 
 
 class newstr(with_metaclass(BaseNewStr, unicode)):
