@@ -1,14 +1,6 @@
 """
 A selection of cross-compatible functions for Python 2 and 3.
 
-These come from several sources:
-
-    * Jinja2 (BSD licensed: see
-      https://github.com/mitsuhiko/jinja2/blob/master/LICENSE)
-    * Pandas compatibility module pandas.compat
-    * six.py by Benjamin Peterson
-    * Django
-
 This exports useful functions for 2/3 compatible code that are not
 builtins on Python 3:
 
@@ -68,12 +60,22 @@ Chinese characters for Confucius::
 
 On Python 3, this decorator is a no-op.
 
+Some of the functions in this module come from the following sources:
+
+    * Jinja2 (BSD licensed: see
+      https://github.com/mitsuhiko/jinja2/blob/master/LICENSE)
+    * Pandas compatibility module pandas.compat
+    * six.py by Benjamin Peterson
+    * Django
 """
 
 import types
 import sys
 import numbers
 import functools
+import copy
+import inspect
+
 
 PY3 = sys.version_info[0] == 3
 PY2 = sys.version_info[0] == 2
@@ -336,7 +338,49 @@ def getexception():
     return sys.exc_info()[1]
 
 
+def _get_caller_globals_and_locals():
+    """
+    Returns the globals and locals of the calling frame.
+
+    Is there an alternative to frame hacking here?
+    """
+    caller_frame = inspect.stack()[2]
+    myglobals = caller_frame[0].f_globals
+    mylocals = caller_frame[0].f_locals
+    return myglobals, mylocals
+
+
+def _repr_strip(mystring):
+    """
+    Returns the string without any initial or final quotes.
+    """
+    r = repr(mystring)
+    if r.startswith("'") and r.endswith("'"):
+        return r[1:-1]
+    else:
+        return r
+
+
 if PY3:
+    def raise_from(exc, cause):
+        """
+        Equivalent to:
+
+            raise EXCEPTION from CAUSE
+
+        on Python 3. (See PEP 3134).
+        """
+        # Is either arg an exception class (e.g. IndexError) rather than
+        # instance (e.g. IndexError('my message here')? If so, pass the
+        # name of the class undisturbed through to "raise ... from ...".
+        if isinstance(exc, type) and issubclass(exc, Exception):
+            exc = exc.__name__
+        if isinstance(cause, type) and issubclass(cause, Exception):
+            cause = cause.__name__
+        execstr = "raise " + _repr_strip(exc) + " from " + _repr_strip(cause)
+        myglobals, mylocals = _get_caller_globals_and_locals()
+        exec(execstr, myglobals, mylocals)
+
     def raise_(tp, value=None, tb=None):
         """
         A function that matches the Python 2.x ``raise`` statement. This
@@ -358,6 +402,40 @@ if PY3:
         raise exc.with_traceback(traceback)
 
 else:
+    def raise_from(exc, cause):
+        """
+        Equivalent to:
+
+            raise EXCEPTION from CAUSE
+
+        on Python 3. (See PEP 3134).
+        """
+        # Is either arg an exception class (e.g. IndexError) rather than
+        # instance (e.g. IndexError('my message here')? If so, pass the
+        # name of the class undisturbed through to "raise ... from ...".
+        if isinstance(exc, type) and issubclass(exc, Exception):
+            e = exc()
+            # exc = exc.__name__
+            # execstr = "e = " + _repr_strip(exc) + "()"
+            # myglobals, mylocals = _get_caller_globals_and_locals()
+            # exec(execstr, myglobals, mylocals)
+        else:
+            e = exc
+        e.__suppress_context__ = False
+        if isinstance(cause, type) and issubclass(cause, Exception):
+            e.__cause__ = cause()
+            e.__suppress_context__ = True
+        elif cause is None:
+            e.__cause__ = None
+            e.__suppress_context__ = True
+        elif isinstance(cause, BaseException):
+            e.__cause__ = cause
+            e.__suppress_context__ = True
+        else:
+            raise TypeError("exception causes must derive from BaseException")
+        e.__context__ = sys.exc_info()[1]
+        raise e
+
     exec('''
 def raise_(tp, value=None, tb=None):
     raise tp, value, tb
@@ -538,8 +616,11 @@ else:
         exec("""exec code in globs, locs""")
 
 
+# Defined here for backward compatibility:
 def old_div(a, b):
     """
+    DEPRECATED: import ``old_div`` from ``past.utils`` instead.
+
     Equivalent to ``a / b`` on Python 2 without ``from __future__ import
     division``.
 
