@@ -15,8 +15,11 @@ Copyright 2013 Python Charmers Pty Ltd, Australia.
 The software is distributed under an MIT licence. See LICENSE.txt.
 """
 
-import sys
+import os
 
 from libfuturize.main import main
-sys.exit(main())
+
+# We use os._exit() because sys.exit() seems to interact badly with
+# subprocess.check_output() ...
+os._exit(main())
 
