@@ -65,8 +65,7 @@ from __future__ import (absolute_import, print_function, unicode_literals)
 from future.builtins import *
 import future
 import future.utils
-
-__version__ = '0.12.4'
+from future import __version__
 
 import sys
 import logging
@@ -83,11 +82,6 @@ from libfuturize.fixes import (lib2to3_fix_names_stage1,
 
 fixer_pkg = 'libfuturize.fixes'
 
-if __version__ != future.__version__:
-    warn('The libfuturize and future packages have different versions. '
-         'This may break the futurize script. Please ensure the versions '
-         'are consistent.')
-
 
 def main(args=None):
     """Main program.
@@ -247,7 +241,7 @@ def main(args=None):
                     # First ensure that no names clash (e.g.
                     # lib2to3.fixes.fix_blah and libfuturize.fixes.fix_blah):
                     found = [f for f in avail_fixes
-                             if f.endswith('fix_{}'.format(fix))]
+                             if f.endswith('fix_{0}'.format(fix))]
                     if len(found) > 1:
                         print("Ambiguous fixer name. Choose a fully qualified "
                               "module name instead from these:\n" +
