@@ -31,7 +31,6 @@ Python 3 with ``pasteurize`` as they are when converting from Python 2 with
 """
 
 from __future__ import (absolute_import, print_function, unicode_literals)
-from future.builtins import *
 
 import sys
 import logging
@@ -40,16 +39,10 @@ from lib2to3.main import main, warn, StdoutRefactoringTool
 from lib2to3 import refactor
 
 import future
+from future import __version__
+from future.builtins import *
 from libpasteurize.fixes import fix_names
 
-__version__ = '0.12.4'
-
-if __version__ != future.__version__:
-    warn('The libfuturize and future packages have different versions. '
-         'This may break the pasteurize script. Please ensure the versions '
-         'are consistent.')
-
-
 
 def main(args=None):
     """Main program.
